@@ -27,6 +27,8 @@ from .imagename import ImageName
 
 LOGGER = logging.getLogger(__name__)
 
+DOCKER_REGISTRY_PORT_INSECURE = 5000
+DOCKER_REGISTRY_PORT_SECURE = 5000
 DOCKER_REGISTRY_SERVICE = "pytest-docker-registry"
 DOCKER_REGISTRY_SERVICE_PATTERN = f"{DOCKER_REGISTRY_SERVICE}-{{0}}-{{1}}"
 
@@ -129,7 +131,7 @@ def generate_htpasswd(
 
 
 def generate_keypair(
-    *, keysize: int = 4096, life_cycle: int = 7 * 24 * 60 * 60
+    *, keysize: int = 4096, life_cycle: int = 7 * 24 * 60 * 60, service_name: str = None
 ) -> CertificateKeypair:
     """
     Generates a keypair and certificate for the registry service.
@@ -137,6 +139,7 @@ def generate_keypair(
     Args:
         keysize: size of the private key.
         life_cycle: Lifespan of the generated certificates, in seconds.
+        service_name: Name of the service to be added as a SAN.
 
     Returns:
         tuple:
@@ -187,6 +190,7 @@ def generate_keypair(
     x509_cert.set_serial_number(randrange(100000))
     x509_cert.set_version(2)
 
+    service_name = [f"DNS:{service_name}"] if service_name else []
     x509_cert.add_extensions(
         [
             crypto.X509Extension(b"basicConstraints", False, b"CA:FALSE"),
@@ -200,6 +204,7 @@ def generate_keypair(
                         f"DNS:*.{getfqdn()}",
                         "DNS:localhost",
                         "DNS:*.localhost",
+                        *service_name,
                         "IP:127.0.0.1",
                     ]
                 ).encode("utf-8"),
@@ -396,7 +401,12 @@ def replicate_manifest_list(
 
 
 def start_service(
-    docker_services: Services, *, docker_compose: Path, service_name: str, **kwargs
+    docker_services: Services,
+    *,
+    docker_compose: Path,
+    private_port: int,
+    service_name: str,
+    **kwargs,
 ):
     # pylint: disable=protected-access
     """
@@ -405,6 +415,7 @@ def start_service(
     Args:
         docker_services: lovely service to use to start the service.
         docker_compose: Path to the docker-compose configuration file (to be injected).
+        private_port: The private port to which the service is bound.
         service_name: Name of the service, within the docker-compose configuration, to be instantiated.
     """
     # DUCK PUNCH: Don't get in the way of user-defined lovey/pytest/docker/compose.py::docker_compose_files()
@@ -413,5 +424,7 @@ def start_service(
         str(docker_compose)
     ]  # pylint: disable=protected-access
     docker_services.start(service_name)
-    public_port = docker_services.wait_for_service(service_name, 5000, **kwargs)
+    public_port = docker_services.wait_for_service(
+        pause=3, private_port=private_port, service=service_name, **kwargs
+    )
     return f"{docker_services.docker_ip}:{public_port}"
